package othello.controlers;



import othello.models.GameModel;
import othello.models.IAModel;
import othello.models.PreferenceModel;

import othello.views.AbootView;
import othello.views.ContentsView;
import othello.views.EndGameView;
import othello.views.GameView;
import othello.views.PreferenceView;
import othello.views.SoundsView;

/**
 * Le contrleur du jeu.
 * @author Jean-Franois Berdjugin
 * Le contrleur contient la logique de navigation, il permet d'afficher les vues.
 *
 */
public class Controler {
	/**
	 * La vue principale qui contient les menus et le plateau
	 */
	private GameView gameView;
	/**
	 * La vue de fin de partie
	 */
	private EndGameView endGameView;
	/**
	 * La vue des prfrences pour le son et les joueurs
	 */
	private PreferenceView preferenceView;
	
	/**
	 * La vue qui permet de jouer la musique et les sons 
	 */
	private SoundsView soundsView;
	
	/**
	 *La vue qui permet  l'IA de determiner le coup  jouer 
	 */
	private IAModel iaView;
	/**
	 * La vue qui contient la documentation 
	 */
	private ContentsView contentsView;
	
	/**
	 * La vue a propos
	 */
	private AbootView abootView;

	/**
	 * Le modle du plateau
	 */
	private GameModel gameModel;
	
	/**
	 *Le modle des prfrences 
	 */
	private PreferenceModel preferenceModel;

	/**
	 * Permet de construire un contrleur qui voit le modle de plateau et le modle des pfrences.
	 * @param gameModel Le modle du plateau de jeu
	 * @param preferenceModel Le modle des prfrences
	 */
	public Controler(GameModel gameModel, PreferenceModel preferenceModel)	{
		this.gameModel = gameModel;
		this.preferenceModel = preferenceModel;

		this.gameView = new GameView(gameModel, this);
		//this.gameView.setBoardActived(false);

		this.gameView.setVisible(true);
		this.endGameView = new EndGameView(this.gameModel, this.gameView, this);
		this.preferenceView = new PreferenceView(this.preferenceModel,this.gameView , this);
		this.soundsView = new SoundsView();
		this.iaView = new IAModel(gameModel, preferenceModel, this);
		this.contentsView = new ContentsView(this.gameView);
		this.abootView = new AbootView(this.gameView);

		if (this.preferenceModel.isBackgroundMusic())
			this.soundsView.playMusic();
		if (this.preferenceModel.getFirstPlayer()!=0)
		{
			this.playXY(0, 0);
		}
	}

	/**
	 * Permet de dclencher une nouvelle partie, modifie le modle du plateau de jeu et la vue principale
	 */
	public void nouvellePartie()
	{
		this.gameModel.initBoard();
		this.soundsView.stopEndMusic();
		if (this.preferenceModel.getFirstPlayer()!=0)
		{
			this.playXY(0, 0);

		}
		else
		{	
			this.gameView.repaint();
		}
	}

	/**
	 * Permet de tenter de jouer un coup
	 * Si un coup ne peut-tre jou la vue de fin est affiche
	 * @param x l'abscisse choisie
	 * @param y l'ordonnee choisie
	 */
	public void playXY(int x, int y) {

		if (this.gameModel.currentUserCanPlay())
		{
			if ((this.gameModel.getCurrentUser() == 1 && this.preferenceModel.getFirstPlayer()!=0)
					||
					(this.gameModel.getCurrentUser() == -1 && this.preferenceModel.getSecondPlayer()!=0))
			{
				int res[] = this.iaView.play();
				x=res[0];
				y=res[1];
			}
			if (this.gameModel.isPlayable(x, y))
			{
				this.gameModel.playXY(x, y);
				if (this.preferenceModel.isSounds())
				{
					if (this.soundsView!=null)
					this.soundsView.playPlay();
				}
					if (this.gameModel.isFull())
				{
					this.gameModel.sort();
					this.gameView.repaint();
					this.soundsView.playEndMusic();
					endGameView.update();
					endGameView.setVisible(true);
				}
				else
				{	
					this.gameModel.swichUser();
					if (!this.gameModel.currentUserCanPlay())
					{
						this.gameModel.swichUser();
						if (!this.gameModel.currentUserCanPlay())
						{
							this.gameModel.sort();
							this.gameView.repaint();
							this.soundsView.playEndMusic();
							endGameView.update();
							endGameView.setVisible(true);
							
						}
					}
					if ((this.gameModel.getCurrentUser() == 1 && this.preferenceModel.getFirstPlayer()!=0)
							||
							(this.gameModel.getCurrentUser() == -1 && this.preferenceModel.getSecondPlayer()!=0))
					{
						this.playXY(0, 0);
					}	

				}	
			}
		}

		this.gameView.repaint();

	}

	/**
	 * Permet de quitter le jeux
	 */
	public void quitter()
	{
		System.exit(0);
	}

	/**
	 * Permet au contrleur de modifier les prfrences sonnores pour les coups jous
	 * @param on true pour les sons et false sinon
	 */
	public void setSounds(boolean on)
	{
		this.preferenceModel.setSounds(on);
	}

	/**
	 * Permet au contrleur de modifier les prfrences sonnores pour la musique de fond
	 * @param on true pour la musique et false sinon
	 */
	public void setMusic(boolean on)
	{
		this.preferenceModel.setBackgroundMusic(on);
		if (on)
			this.soundsView.playMusic();
		else
			this.soundsView.stopMusic();
	}

	/**
	 * Permet au contrleur de modifier les preferences pour le premier joueur 
	 * @param level 0 humain autre ordinateur
	 */
	public void setFirstPlayer(int level)
	{
		this.preferenceModel.setFirstPlayer(level);
	}
	/**
	 * Permet au contrleur de modifier les preferences pour le second joueur  
	 * @param level 0 humain autre ordinateur
	 */
	public void setSecondPlayer(int level)
	{
		this.preferenceModel.setSecondPlayer(level);
	}

	/**
	 * Affiche la vue preferences
	 */
	public void displayPreferences()
	{
		this.preferenceView.setVisible(true);
	}

	/**
	 * Affiche la vue contents (les rgles du jeux)
	 */
	public void displayContents()
	{
		this.contentsView.setVisible(true);
	}

	/**
	 * Affiche la vue  propos
	 */
	public void displayAboutView()
	{
		this.abootView.setVisible(true);
	}
}
