package othello.views;

import java.awt.Event;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.net.URL;

import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;

import othello.controlers.Controler;
import othello.models.GameModel;
import utils.ImageUtils;



/**
 * La fentre principale du jeu.
 * @author Jean-Franois Berdjugin
 * La fentre principale contient les menus, elle doit connatre le contrleur et le modle du jeu.
 * Elle contient le plateau de jeu.  
 */
public class GameView extends JFrame implements ActionListener{
	/**
	 * 
	 */
	private static final long serialVersionUID = 7630246509467804669L;
	/**
	 * Le controleur du jeu
	 */
	private Controler controler;
	/**
	 * Le plateau de jeu
	 */
	private GameBoard plateauJeu;
	/**
	 * La barre de menu
	 */
	private JMenuBar menuBar;
	/**
	 * Le menu jeu 
	 */
	private JMenu menuJeu;
	/**
	 * Le menu paramtres
	 */
	private JMenu menuParametres;
	/**
	 * Le menu aide
	 */
	private JMenu menuAide;
	/**
	 * L'lment de menu nouvelle partie
	 */
	private JMenuItem menuItemNouvellePartie;
	/**
	 * L'lment de menu quitter
	 */
	private JMenuItem menuItemQuitter;
	/**
	 * 	
	 * L'lment de menu prfrences
	 */
	private JMenuItem menuItemPreferences;
	/**
	 * L'lment de menu sommaire
	 */
	private JMenuItem menuItemSommaire;
	/**
	 * L'lment de menu  propos
	 */
	private JMenuItem menuItemAPropos;

	/**
	 * Le constructeur de la vue 
	 * @param model le modle du jeu
	 * @param controler le contrleur du jeu
	 */
	public GameView(GameModel model, Controler controler)
	{
		super("Othello");
		this.controler = controler;

		this.setDefaultCloseOperation(EXIT_ON_CLOSE);
		this.setResizable(false);

		this.plateauJeu = new GameBoard(model,controler);

		this.add(plateauJeu);

		this.menuBar = new JMenuBar();
		this.menuJeu = new JMenu("Jeu");
		this.menuJeu.setMnemonic(KeyEvent.VK_J);
		URL url;
		url = this.getClass().getClassLoader().getResource("ressources/icon/nouvelle_partie.png");
		this.menuItemNouvellePartie = new JMenuItem("Nouvelle Partie",ImageUtils.resizeImageIcon(url));
		this.menuItemNouvellePartie.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_N, Event.CTRL_MASK, true));





		url = this.getClass().getClassLoader().getResource("ressources/icon/quitter.png");

		this.menuItemQuitter = new JMenuItem("Quitter",ImageUtils.resizeImageIcon(url));
		this.menuItemQuitter.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Q, Event.CTRL_MASK, true));


		this.menuJeu.add(menuItemNouvellePartie);
		this.menuJeu.add(menuItemQuitter);
		this.menuBar.add(menuJeu);


		this.menuParametres = new JMenu("Paramtres");
		this.menuParametres.setMnemonic(KeyEvent.VK_P);

		url = this.getClass().getClassLoader().getResource("ressources/icon/preferences.png");
		this.menuItemPreferences = new JMenuItem("Prfrences",ImageUtils.resizeImageIcon(url));

		this.menuParametres.add(menuItemPreferences);

		this.menuBar.add(menuParametres);

		this.menuAide = new JMenu("Aide");
		this.menuAide.setMnemonic(KeyEvent.VK_E);

		url = this.getClass().getClassLoader().getResource("ressources/icon/sommaire.png");
		this.menuItemSommaire = new JMenuItem("Sommaire",ImageUtils.resizeImageIcon(url));
		this.menuItemSommaire.setAccelerator(KeyStroke.getKeyStroke("F1"));
		this.menuAide.add(menuItemSommaire);
		this.menuAide.addSeparator();
		url = this.getClass().getClassLoader().getResource("ressources/icon/a_propos.png");
		this.menuItemAPropos=new JMenuItem("A propos",ImageUtils.resizeImageIcon(url));
		this.menuAide.add(menuItemAPropos);
		this.menuBar.add(menuAide);

		this.setJMenuBar(menuBar);
		this.menuItemQuitter.addActionListener(this);
		this.menuItemNouvellePartie.addActionListener(this);
		this.menuItemPreferences.addActionListener(this);
		this.menuItemSommaire.addActionListener(this);
		this.menuItemAPropos.addActionListener(this);
		this.pack();
	}

	
	
	
	
	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		Object object = e.getSource();
		if (object.equals(menuItemQuitter))
		{
			this.controler.quitter();
		}
		if (object.equals(menuItemNouvellePartie))
		{
			this.controler.nouvellePartie();
		}
		if (object.equals(menuItemPreferences))
		{
			this.controler.displayPreferences();
		}
		if (object.equals(menuItemSommaire))
		{
			this.controler.displayContents();
			
		}
		if (object.equals(menuItemAPropos))
		{
			this.controler.displayAboutView();
		}
	}
	
}
