package othello.views;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dialog;
import java.awt.GridLayout;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTabbedPane;

import othello.controlers.Controler;
import othello.models.PreferenceModel;
import utils.ImageUtils;

/**
 * La vue des prfrences.
 * @author Jean-Franois Berdjugin
 *Cette vue permet de choisir les joueur et leur niveau pour l'ordinateur.
 *Elle permet aussi de choisir les prfrences sonores
 *Elle doit connatre le contrleur du jeu, le modle de prfrence et la fentre parent.
 */
public class PreferenceView extends JDialog implements ActionListener{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1203846589086620819L;
	/**
	 * Le contrleur du jeu 
	 */
	private Controler controler;
	/**
	 * Le modle du jeu
	 */
	private PreferenceModel model;
	/**
	 * Les boutons pour choisir les joueurs
	 */
	private JRadioButton[][] radioButton;
	/**
	 * La checkbox pour le son 
	 */
	private JCheckBox music;
	/**
	 * La checkbox pour la musique
	 */
	private JCheckBox sounds;

	/**
	 * Le constructeur de la vue prfrence
	 * @param model le modle du jeu
	 * @param parent la fentre parent
	 * @param controler le contrleur du jeu
	 */
	public PreferenceView(PreferenceModel model, Window parent, Controler controler)
	{
		super(parent, "Prfrences", Dialog.ModalityType.MODELESS);
		this.setDefaultCloseOperation(HIDE_ON_CLOSE);
		this.controler=controler;
		this.model = model;
		this.getContentPane().setBackground(Color.gray);
		ButtonGroup whiteGroup, blackGroup;
		whiteGroup = new ButtonGroup();
		blackGroup = new ButtonGroup();

		this.radioButton = new JRadioButton[2][4];
		radioButton[0][0]= new JRadioButton("Humain");
		radioButton[1][0]= new JRadioButton("Humain");
		radioButton[0][1]= new JRadioButton("Niveau un");
		radioButton[1][1]= new JRadioButton("Niveau un");
		radioButton[0][2]= new JRadioButton("Niveau deux");
		radioButton[1][2]= new JRadioButton("Niveau deux");
		radioButton[0][3]= new JRadioButton("Niveau trois");
		radioButton[1][3]= new JRadioButton("Niveau trois");
		for (int i=0; i <4; i++)
		{
			blackGroup.add(radioButton[0][i]);
			if (this.model.getFirstPlayer() == i)
				radioButton[0][i].setSelected(true);
			whiteGroup.add(radioButton[1][i]);
			if (this.model.getSecondPlayer() == i)
				radioButton[1][i].setSelected(true);
			radioButton[0][i].setBackground(Color.gray);
			radioButton[1][i].setBackground(Color.gray);
		}
		
		JPanel panelUp = new JPanel(new GridLayout(5,2));
		panelUp.setBackground(Color.gray);
		panelUp.setBorder(BorderFactory.createLineBorder(Color.black));
		panelUp.add(new JLabel("Noir"));
		panelUp.add(new JLabel("Blanc"));
		for (int i=0; i <4; i++)
			for (int j=0; j<2; j++)
				panelUp.add(radioButton[j][i]);

		JPanel panelDown = new JPanel(new GridLayout(2,1));
		panelDown.setBackground(Color.gray);

		this.music = new JCheckBox("Musique de fond");
		this.music.setBackground(Color.gray);
		this.sounds = new JCheckBox("Sons");
		this.sounds.setBackground(Color.gray);
		this.music.setSelected(this.model.isBackgroundMusic());
		this.sounds.setSelected(this.model.isSounds());
		panelDown.add(this.music);
		panelDown.add(this.sounds);
		
		JPanel panel = new JPanel(new BorderLayout());
		panel.add(panelUp,BorderLayout.CENTER);
		panel.add(panelDown,BorderLayout.SOUTH);
		JTabbedPane pane = new JTabbedPane();
		URL url = this.getClass().getClassLoader().getResource("ressources/icon/jeu_preferences.png");
		pane.addTab("Jeu", ImageUtils.resizeImageIcon(url) ,panel,"Les paramtres du jeu");
		
		this.add(pane);
		this.pack();
		this.setResizable(false);
		this.music.addActionListener(this);
		this.sounds.addActionListener(this);
		for (int i=0; i <4; i++)
			for (int j=0; j<2; j++)
				this.radioButton[j][i].addActionListener(this);
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		this.controler.setMusic(this.music.isSelected());
		this.controler.setSounds(this.sounds.isSelected());
		for (int i=0; i <4; i++)
		{
			if (radioButton[0][i].isSelected())
				this.controler.setFirstPlayer(i);
			if (radioButton[1][i].isSelected())
				this.controler.setSecondPlayer(i);
		}
	}
}
